@@ -1,4 +1,4 @@
-"""The Api adaptors provide sources and stores using API endpoints.
+"""The Api source gets data from an API endpoints.
 Requires the requests library to be installed.
 """
 from sinai.adaptors.api import ApiConnection
