@@ -10,7 +10,7 @@ from sinai.types import JDict, MetricList
 class Source(BaseView):
     """Any data source (base class)."""
 
-    def get_data(self, argument: Any) -> Any:
+    def get_data(self, request: JDict) -> Any:
         """Some sources can get their data at initialisation,
         others need to wait for the Rule to request it.
         This method is for that latter case.
